@@ -1,7 +1,7 @@
-package Dist::Zilla::Plugin::Test::CheckDeps; # git description: v0.012-22-g830c81b
+package Dist::Zilla::Plugin::Test::CheckDeps; # git description: v0.013-8-g41c9a1a
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.013';
+our $VERSION = '0.014';
 
 use Moose;
 extends qw/Dist::Zilla::Plugin::InlineFiles/;
@@ -42,6 +42,7 @@ around dump_config => sub {
     $config->{+__PACKAGE__} = {
         (map { $_ => $self->$_ } qw(todo_when level filename)),
         fatal => $self->fatal ? 1 : 0,
+        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
 
     return $config;
@@ -67,7 +68,11 @@ around add_file => sub {
 
 sub register_prereqs {
     my $self = shift;
-    $self->zilla->register_prereqs({ phase => 'test' }, 'Test::More' => '0.94', 'Test::CheckDeps' => '0.010');
+    $self->zilla->register_prereqs(
+        { phase => 'test', type => 'requires' },
+        'Test::More' => '0.94',
+        'Test::CheckDeps' => '0.010',
+    );
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -126,7 +131,7 @@ Dist::Zilla::Plugin::Test::CheckDeps - Check for presence of dependencies
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
@@ -166,6 +171,17 @@ F<t/00-check-deps.t>.
 
 =for Pod::Coverage register_prereqs
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Test-CheckDeps>
+(or L<bug-Dist-Zilla-Plugin-Test-CheckDeps@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Test-CheckDeps@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
 =head1 AUTHOR
 
 Leon Timmermans <leont@cpan.org>
@@ -190,7 +206,7 @@ Brendan Byrd <GitHub@ResonatorSoft.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2011 by Leon Timmermans.
 
@@ -204,7 +220,7 @@ ___[ test-checkdeps ]___
 use strict;
 use warnings;
 
-# this test was generated with {{ ref($plugin) . ' ' . $plugin->VERSION }}
+# this test was generated with {{ ref $plugin }} {{ $plugin->VERSION }}
 
 use Test::More 0.94;
 {{
